@@ -22,26 +22,23 @@
 
 #include "config.h"
 
+#include "eggsmclient.h"
+#include "ephy-debug.h"
+#include "ephy-file-helpers.h"
+#include "ephy-session.h"
 #include "ephy-settings.h"
 #include "ephy-shell.h"
-#include "ephy-file-helpers.h"
 #include "ephy-state.h"
-#include "ephy-debug.h"
 #include "ephy-stock-icons.h"
-#include "ephy-session.h"
-#include "ephy-shell.h"
-#include "ephy-debug.h"
 #include "ephy-string.h"
-#include "eggsmclient.h"
-
-#include <libxml/xmlversion.h>
-
-#include <glib/gi18n.h>
-
-#include <gdk/gdkx.h>
-#include <gtk/gtk.h>
+#include "ephy-web-app-utils.h"
 
 #include <errno.h>
+#include <gdk/gdkx.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <libnotify/notify.h>
+#include <libxml/xmlversion.h>
 #include <string.h>
 
 #ifdef ENABLE_INTROSPECTION
@@ -60,6 +57,7 @@ static char *session_filename = NULL;
 static char *bookmark_url = NULL;
 static char *bookmarks_file = NULL;
 static char **arguments = NULL;
+static char *application_to_delete = NULL;
 
 /* Only set from options in debug builds */
 static gboolean private_instance = FALSE;
@@ -103,6 +101,8 @@ static const GOptionEntry option_entries[] =
     "", N_("URL …")},
   { "version", 0, G_OPTION_FLAG_NO_ARG | G_OPTION_FLAG_HIDDEN, 
     G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL },
+  { "delete-application", 0, 0, G_OPTION_ARG_STRING | G_OPTION_FLAG_HIDDEN,
+    &application_to_delete, NULL, NULL },
   { NULL }
 };
 
@@ -253,16 +253,12 @@ main (int argc,
   textdomain (GETTEXT_PACKAGE);
 #endif
 
-  /* Threads have to be initialised before calling ANY glib function */
-  g_thread_init (NULL);
-
   /* check libxml2 API version epiphany was compiled with against the
    * version we're running with.
    */
   LIBXML_TEST_VERSION;
 
-  /* sets name to help matching with the .desktop file */
-  g_set_prgname ("epiphany");
+  notify_init (PACKAGE);
 
   /* If we're given -remote arguments, translate them */
   if (argc >= 2 && strcmp (argv[1], "-remote") == 0) {
@@ -359,11 +355,21 @@ main (int argc,
   g_option_context_free (option_context);
 
   /* Some argument sanity checks*/
+  if (application_to_delete != NULL && argc > 3) {
+    g_print ("Cannot pass any other parameter when using --delete-application\n");
+    exit (1);
+  }
+
   if (arguments != NULL && (session_filename != NULL || open_as_bookmarks_editor)) {
     g_print ("Cannot use --bookmarks-editor or --load-session with URL arguments  \n");
     exit (1);
   }
 
+  if (private_instance == TRUE && application_mode == TRUE) {
+    g_print ("Cannot use --private-instance and --application-mode at the same time\n");
+    exit (1);
+  }
+
   if (profile_directory != NULL && private_instance == FALSE && application_mode == FALSE) {
     g_print ("--profile can only be used in combination with --private-instance or --application-mode\n");
     exit (1);
@@ -400,12 +406,6 @@ main (int argc,
   if (user_time == 0)
       user_time = slowly_and_stupidly_obtain_timestamp (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()));
 
-  /* sets the name to appear in the window list applet when grouping windows */
-  g_set_application_name (_("Web Browser"));
-
-  /* Set default window icon */
-  gtk_window_set_default_icon_name (EPHY_STOCK_EPHY);
-
   startup_error_quark = g_quark_from_static_string ("epiphany-startup-error");
 
   /* Start our services */
@@ -417,6 +417,13 @@ main (int argc,
     exit (1);
   }
 
+  /* Delete the requested web application, if any. Must happen after
+   * ephy_file_helpers_init (). */
+  if (application_to_delete) {
+    ephy_web_application_delete (application_to_delete);
+    exit (0);
+  }
+
   ephy_stock_icons_init ();
   ephy_file_load_accels ();
 
@@ -426,11 +433,31 @@ main (int argc,
   /* Now create the shell */
   if (private_instance)
     mode = EPHY_EMBED_SHELL_MODE_PRIVATE;
-  else if (application_mode)
+  else if (application_mode) {
+    char *app_name;
+
     mode = EPHY_EMBED_SHELL_MODE_APPLICATION;
-  else
+
+    app_name = g_strrstr (profile_directory, EPHY_WEB_APP_PREFIX);
+    if (app_name) {
+      /* Skip the 'app-' part */
+      app_name += strlen (EPHY_WEB_APP_PREFIX);
+
+      g_set_prgname (app_name);
+      g_set_application_name (app_name);
+
+      /* We need to re-set this because we have already parsed the
+       * options, which inits GTK+ and sets this as a side effect. */
+      gdk_set_program_class (app_name);
+    }
+  } else {
     mode = EPHY_EMBED_SHELL_MODE_BROWSER;
 
+    g_set_prgname ("epiphany");
+    g_set_application_name (_("Web Browser"));
+    gtk_window_set_default_icon_name (EPHY_STOCK_EPHY);
+  }
+
   _ephy_shell_create_instance (mode);
 
   startup_flags = get_startup_flags ();
@@ -447,6 +474,9 @@ main (int argc,
   /* Shutdown */
   g_object_unref (ephy_shell);
 
+  if (notify_is_initted ())
+    notify_uninit ();
+
   ephy_file_save_accels ();
   ephy_state_save ();
   ephy_settings_shutdown ();
