@@ -223,7 +223,7 @@ create_node_combo (EphyDialog *dialog,
 	GtkComboBox *combo;
 	GtkCellRenderer *renderer;
 	char *code;
-	int title_col, data_col;
+	int title_col;
 
 	code = g_settings_get_string (EPHY_SETTINGS_WEB,
 				      EPHY_PREFS_WEB_DEFAULT_ENCODING);
@@ -243,8 +243,9 @@ create_node_combo (EphyDialog *dialog,
 
 	title_col = ephy_tree_model_node_add_prop_column
 			(nodemodel, G_TYPE_STRING, EPHY_NODE_ENCODING_PROP_TITLE_ELIDED);
-	data_col = ephy_tree_model_node_add_prop_column
-			(nodemodel, G_TYPE_STRING, EPHY_NODE_ENCODING_PROP_ENCODING);
+
+	ephy_tree_model_node_add_prop_column
+		(nodemodel, G_TYPE_STRING, EPHY_NODE_ENCODING_PROP_ENCODING);
 
 	sortmodel = ephy_tree_model_sort_new (GTK_TREE_MODEL (nodemodel));
 
@@ -1023,6 +1024,9 @@ static const PrefsDialogPreference preferences[] =
 	{ "css_edit_button", "sensitive",
 	  EPHY_PREFS_WEB_SCHEMA, EPHY_PREFS_WEB_ENABLE_USER_CSS,
 	  G_SETTINGS_BIND_GET, NULL, NULL },
+	{ "enable_spell_checking_checkbutton", "active",
+	  EPHY_PREFS_WEB_SCHEMA, EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING,
+	  G_SETTINGS_BIND_DEFAULT, NULL, NULL },
 
 	/* Font buttons */
 	{ "custom_fonts_table", "sensitive",
